summaryrefslogtreecommitdiffstats
path: root/ash/wm/shelf_layout_manager.cc
diff options
context:
space:
mode:
authoroshima@chromium.org <oshima@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-06-27 22:21:47 +0000
committeroshima@chromium.org <oshima@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-06-27 22:21:47 +0000
commit2e236a564aa06711455408a2b13ac8f52ac79343 (patch)
tree04478bff847bfd8b6d90437bf79f41a5caf0b398 /ash/wm/shelf_layout_manager.cc
parent56827e84ada3c06d8533e01d2fa739f0cb432fa8 (diff)
downloadchromium_src-2e236a564aa06711455408a2b13ac8f52ac79343.zip
chromium_src-2e236a564aa06711455408a2b13ac8f52ac79343.tar.gz
chromium_src-2e236a564aa06711455408a2b13ac8f52ac79343.tar.bz2
Relanding r144499:
Rename the remaining usage of Monitor to Display BUG=none TEST=none Committed: http://src.chromium.org/viewvc/chrome?view=rev&revision=144499 Review URL: https://chromiumcodereview.appspot.com/10675011 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@144585 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash/wm/shelf_layout_manager.cc')
-rw-r--r--ash/wm/shelf_layout_manager.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/ash/wm/shelf_layout_manager.cc b/ash/wm/shelf_layout_manager.cc
index 3c3246f..156fad1 100644
--- a/ash/wm/shelf_layout_manager.cc
+++ b/ash/wm/shelf_layout_manager.cc
@@ -206,7 +206,7 @@ bool ShelfLayoutManager::SetAlignment(ShelfAlignment alignment) {
}
gfx::Rect ShelfLayoutManager::GetIdealBounds() {
// TODO: this is wrong. Figure out what monitor shelf is on and everything
// should be based on it.
gfx::Rect bounds(
gfx::Screen::GetDisplayNearestWindow(status_->GetNativeView()).bounds());
@@ -239,7 +239,7 @@ void ShelfLayoutManager::LayoutShelf() {
}
GetLayer(status_)->SetOpacity(target_bounds.opacity);
status_->SetBounds(target_bounds.status_bounds);
- Shell::GetInstance()->SetMonitorWorkAreaInsets(
+ Shell::GetInstance()->SetDisplayWorkAreaInsets(
Shell::GetPrimaryRootWindow(),
target_bounds.work_area_insets);
UpdateHitTestBounds();
@@ -384,7 +384,7 @@ void ShelfLayoutManager::SetState(VisibilityState visibility_state) {
status_animation_setter.SetTweenType(ui::Tween::EASE_OUT);
GetLayer(status_)->SetBounds(target_bounds.status_bounds);
GetLayer(status_)->SetOpacity(target_bounds.opacity);
- Shell::GetInstance()->SetMonitorWorkAreaInsets(
+ Shell::GetInstance()->SetDisplayWorkAreaInsets(
Shell::GetPrimaryRootWindow(),
target_bounds.work_area_insets);
UpdateHitTestBounds();
@@ -206,7 +206,7 @@ bool ShelfLayoutManager::SetAlignment(ShelfAlignment alignment) {
}
gfx::Rect ShelfLayoutManager::GetIdealBounds() {
- // TODO: this is wrong. Figure out what monitor shelf is on and everything
+ // TODO: this is wrong. Figure out what display shelf is on and everything
// should be based on it.
gfx::Rect bounds(